@@ -171,8 +171,8 @@ def ProfileMiddleware(application):
                     so.append( format_stats(stats, sort='cumulative') )
 
                     from cgi import escape
-                    splitor = "\n"+"=*"*60+"\n\n\n"
-                    so = escape(splitor.join(so))
+                    splitor = """\n<hr style="border:0;border-bottom:1px dashed;margin:20px 0">\n"""
+                    so = escape(splitor.join(i.strip() for i in so))
                     so = """<pre style="clear:both;padding:1em;background:#ffffde;color:#033">\n%s\n</pre>"""%so
                     result = "%s %s"%(result, so)
                 return result
